
import { lazy, Suspense } from "react";
import { Toaster } from "@/components/ui/toaster";
import { Toaster as Sonner } from "@/components/ui/sonner";
import { TooltipProvider } from "@/components/ui/tooltip";
import { QueryClient, QueryClientProvider } from "@tanstack/react-query";
import { BrowserRouter, Routes, Route, Navigate } from "react-router-dom";
import { Helmet } from "react-helmet";
import { AuthProvider } from "@/contexts/AuthContext";
import { ProtectedRoute } from "@/components/auth/ProtectedRoute";

const PageLoader = () => (
  <div className="min-h-screen flex items-center justify-center">
    <div className="animate-pulse flex space-x-2">
      <div className="h-3 w-3 bg-navy-500 rounded-full"></div>
      <div className="h-3 w-3 bg-navy-500 rounded-full"></div>
      <div className="h-3 w-3 bg-navy-500 rounded-full"></div>
    </div>
  </div>
);

const lazyLoad = (importFn) => {
  const Component = lazy(importFn);
  return (props) => (
    <Suspense fallback={<PageLoader />}>
      <Component {...props} />
    </Suspense>
  );
};

const Home = lazyLoad(() => import("./pages/Index"));
const PreQualification = lazyLoad(() => import("./pages/PreQualification"));
const Auth = lazyLoad(() => import("./pages/Auth"));
const Dashboard = lazyLoad(() => import("./pages/Dashboard"));
const Profile = lazyLoad(() => import("./pages/Profile"));
const About = lazyLoad(() => import("./pages/About"));
const Programs = lazyLoad(() => import("./pages/Programs"));
const FAQ = lazyLoad(() => import("./pages/FAQ"));
const Contact = lazyLoad(() => import("./pages/Contact"));
const NotFound = lazyLoad(() => import("./pages/NotFound"));
const EB5 = lazyLoad(() => import("./pages/programs/EB5"));
const E2 = lazyLoad(() => import("./pages/programs/E2"));
const GoldCard = lazyLoad(() => import("./pages/programs/GoldCard"));
const O1 = lazyLoad(() => import("./pages/programs/O1"));
const Knowledge = lazyLoad(() => import("./pages/Knowledge"));
const BlogPost = lazyLoad(() => import("./pages/BlogPost"));
const VisaQuiz = lazyLoad(() => import("./pages/VisaQuiz"));
const Privacy = lazyLoad(() => import("./pages/Privacy"));
const Terms = lazyLoad(() => import("./pages/Terms"));
const Disclosures = lazyLoad(() => import("./pages/Disclosures"));
const KnowledgeAll = lazyLoad(() => import("./pages/KnowledgeAll"));
const Documents = lazyLoad(() => import("./pages/Documents"));

const queryClient = new QueryClient({
  defaultOptions: {
    queries: {
      refetchOnWindowFocus: false,
      staleTime: 5 * 60 * 1000, // 5 minutes
    },
  },
});

const SiteMap = () => {
  window.location.href = '/sitemap.xml';
  return null;
};

const App = () => {
  return (
    <QueryClientProvider client={queryClient}>
      <TooltipProvider>
        <Helmet>
          <title>Liberty Capital Immigration & Funding</title>
          <meta name="description" content="Expert guidance on immigration pathways and investment funding solutions." />
          <meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=no" />
          <meta name="theme-color" content="#ffffff" />
          <link rel="sitemap" type="application/xml" href="/sitemap.xml" />
        </Helmet>
        <BrowserRouter>
          <AuthProvider>
            <Routes>
              <Route path="/" element={<Home />} />
              <Route path="/prequal" element={<PreQualification />} />
              <Route path="/auth" element={<Auth />} />
              <Route path="/about" element={<About />} />
              <Route path="/programs" element={<Programs />} />
              <Route path="/faq" element={<FAQ />} />
              <Route path="/contact" element={<Contact />} />
              <Route path="/visa-quiz" element={<VisaQuiz />} />
              
              <Route path="/dashboard" element={
                <ProtectedRoute>
                  <Dashboard />
                </ProtectedRoute>
              } />
              
              <Route path="/profile" element={
                <ProtectedRoute>
                  <Profile />
                </ProtectedRoute>
              } />
              
              <Route path="/login" element={<Navigate to="/auth" state={{ activeTab: 'login' }} replace />} />
              <Route path="/signup" element={<Navigate to="/auth" replace />} />
              
              <Route path="/programs/eb5" element={<EB5 />} />
              <Route path="/programs/e2" element={<E2 />} />
              <Route path="/programs/gold-card" element={<GoldCard />} />
              <Route path="/programs/o1" element={<O1 />} />
              
              <Route path="/knowledge" element={<Knowledge />} />
              <Route path="/blog/:slug" element={<BlogPost />} />
              
              <Route path="/privacy" element={<Privacy />} />
              <Route path="/terms" element={<Terms />} />
              <Route path="/disclosures" element={<Disclosures />} />
              
              <Route path="/careers" element={<Navigate to="/contact" replace />} />
              
              <Route path="/knowledge/all" element={<KnowledgeAll />} />
              
              <Route path="/documents" element={<Documents />} />
              
              <Route path="/sitemap.xml" element={<SiteMap />} />
              
              <Route path="*" element={<NotFound />} />
            </Routes>
          </AuthProvider>
        </BrowserRouter>
        <Toaster />
        <Sonner />
      </TooltipProvider>
    </QueryClientProvider>
  );
};

export default App;
